@@ -13,25 +13,23 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
-#ifndef _BABL_H
-#error  this file is only to be included by babl.h 
-#endif
+#ifndef _BABL_EXTENSION_H
+#define _BABL_EXTENSION_H
+
 
 /****************************************************************/
 /* BablExtension */
-BABL_NAMED_CLASS (extension);
+BABL_CLASS_DECLARE (extension);
 /*
  * BablExtension objects are only used internally in babl.
  */
-Babl *babl_extension_id     (int id);
-void  babl_extension_each   (BablEachFunction  each_fun,
-                        void             *user_data);
-Babl * babl_extension       (const char       *name);
-Babl * babl_extension_new   (void             *first_arg,
-                        ...) BABL_ARG_NULL_TERMINATED;
+
+const  Babl * babl_extension               (const char *name);
+void          babl_extension_load_dir_list (const char *dir_list,
+                                            const char **exclusion_patterns);
 
 typedef struct
 {
@@ -39,3 +37,5 @@ typedef struct
   void          *dl_handle;
   void         (*destroy) (void);
 } BablExtension;
+
+#endif
